#include <gtk/gtk.h>

gboolean
on_eventbox_magick_event ( GtkWidget *widget,
                           GdkEvent *event,
                           gpointer user_data );

void
on_togglebutton_magick_start_toggled ( GtkToggleButton *togglebutton,
                                       gpointer user_data );

void
on_optionmenu_magick_filter_clicked ( GtkButton *button,
                                      gpointer user_data );

void
on_optionmenu_magick_filter_pressed ( GtkButton *button,
                                      gpointer user_data );

void
on_optionmenu_magick_filter_state_changed
( GtkWidget *widget,
  GtkStateType state,
  gpointer user_data );

gboolean
on_optionmenu_magick_filter_button_release_event
( GtkWidget *widget,
  GdkEventButton *event,
  gpointer user_data );
void
on_notebook_magick_switch_page ( GtkNotebook *notebook,
                                 GtkNotebookPage *page,
                                 gint page_num,
                                 gpointer user_data );



gboolean
on_hscale_transition_start_button_press_event
( GtkWidget *widget,
  GdkEventButton *event,
  gpointer user_data );

gboolean
on_hscale_transition_start_button_release_event
( GtkWidget *widget,
  GdkEventButton *event,
  gpointer user_data );

gboolean
on_hscale_transition_end_button_press_event
( GtkWidget *widget,
  GdkEventButton *event,
  gpointer user_data );

gboolean
on_hscale_transition_end_button_release_event
( GtkWidget *widget,
  GdkEventButton *event,
  gpointer user_data );

void
on_togglebutton_advanced_toggled ( GtkToggleButton *togglebutton,
                                   gpointer user_data );

gboolean
on_eventbox_magick_event ( GtkWidget *widget,
                           GdkEvent *event,
                           gpointer user_data );

void
on_button_magick_file_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_spinbutton_magick_start_value_changed
                                        (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_spinbutton_magick_end_value_changed (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

gboolean
on_entry_magick_start_focus_out_event  (GtkWidget       *widget,
                                        GdkEventFocus   *event,
                                        gpointer         user_data);

void
on_entry_magick_start_activate         (GtkEntry        *entry,
                                        gpointer         user_data);

gboolean
on_entry_magick_end_focus_out_event    (GtkWidget       *widget,
                                        GdkEventFocus   *event,
                                        gpointer         user_data);

void
on_entry_magick_end_activate           (GtkEntry        *entry,
                                        gpointer         user_data);
